@@ -69,33 +69,8 @@ xfs_probe (PedGeometry* geom)
 	return NULL;
 }
 
-#ifndef DISCOVER_ONLY
-static int
-xfs_clobber (PedGeometry* geom)
-{
-	char	buf[512];
-
-	memset (buf, 0, 512);
-	return ped_geometry_write (geom, buf, XFS_SB_DADDR, 1);
-}
-#endif /* !DISCOVER_ONLY */
-
 static PedFileSystemOps xfs_ops = {
 	probe:		xfs_probe,
-#ifndef DISCOVER_ONLY
-	clobber:	xfs_clobber,
-#else
-	clobber:	NULL,
-#endif
-	open:		NULL,
-	create:		NULL,
-	close:		NULL,
-	check:		NULL,
-	copy:		NULL,
-	resize:		NULL,
-	get_create_constraint:	NULL,
-	get_resize_constraint:	NULL,
-	get_copy_constraint:	NULL
 };
 
 static PedFileSystemType xfs_type = {
