@@ -150,7 +150,7 @@ enum failure {
 	unable_to_read
 };
 
-static char buffer[85];
+static char buffer[89];
 
 static void
 vtoc_error (enum failure why, char const *s1, char const *s2)
@@ -257,7 +257,7 @@ void
 vtoc_volume_label_init (volume_label_t *vlabel)
 {
 	PDEBUG
-	sprintf(buffer, "%84s", " ");
+	sprintf(buffer, "%88s", " ");
 	vtoc_ebcdic_enc(buffer, buffer, sizeof *vlabel);
 	memcpy(vlabel, buffer, sizeof *vlabel);
 }
@@ -269,6 +269,28 @@ int
 vtoc_read_volume_label (int f, unsigned long vlabel_start,
                         volume_label_t *vlabel)
 {
+
+	char str[5];
+	unsigned long block_zero;
+	typedef struct bogus_label bogus_label_t;
+	typedef union vollabel vollabel_t;
+
+	union __attribute__((packed)) vollabel {
+		volume_label_t cdl;
+		ldl_volume_label_t ldl;
+		cms_volume_label_t cms;
+	};
+
+	struct  __attribute__((packed)) bogus_label {
+	   char overhead[512];
+	   vollabel_t actual_label;
+	};
+
+	bogus_label_t mybogus;
+	bogus_label_t *bogus_ptr = &mybogus;
+	vollabel_t *union_ptr = &bogus_ptr->actual_label;
+	volume_label_t *cdl_ptr = &union_ptr->cdl;
+
 	PDEBUG
 	int rc;
 
@@ -279,12 +301,43 @@ vtoc_read_volume_label (int f, unsigned long vlabel_start,
 	}
 
 	rc = read(f, vlabel, sizeof(volume_label_t));
-	if (rc != sizeof(volume_label_t)) {
+	if (rc != sizeof(volume_label_t) &&
+	/* For CDL we ask to read 88 bytes, but only get 84 */
+            rc != sizeof(volume_label_t) - 4) {
 		vtoc_error(unable_to_read, "vtoc_read_volume_label",
 			   _("Could not read volume label."));
 		return 1;
 	}
 
+	if (strncmp(vlabel->volkey, vtoc_ebcdic_enc("VOL1", str, 4), 4) == 0
+	 || strncmp(vlabel->volkey, vtoc_ebcdic_enc("LNX1", str, 4), 4) == 0
+         || strncmp(vlabel->volkey, vtoc_ebcdic_enc("CMS1", str, 4), 4) == 0)
+	return 0;
+
+	/*
+	   If we didn't find a valid volume label, there is a special case
+           we must try before we give up.  For a CMS-formatted disk on FBA
+	   DASD using the DIAG driver and a block size greater than 512, we
+	   must read the block at offset 0, then look for a label within
+	   that block at offset 512.
+	*/
+
+	block_zero = 0;
+
+	if (lseek(f, block_zero, SEEK_SET) == -1) {
+		vtoc_error(unable_to_seek, "vtoc_read_volume_label",
+			   _("Could not read volume label."));
+		return 1;
+	}
+
+	rc = read(f, bogus_ptr, sizeof(bogus_label_t));
+	if (rc != sizeof(bogus_label_t)) {
+		vtoc_error(unable_to_read, "vtoc_read_volume_label",
+			   _("Could not read volume label."));
+		return 1;
+	}
+
+	memcpy(vlabel, cdl_ptr, sizeof *vlabel);
 	return 0;
 }
 
@@ -302,8 +355,10 @@ vtoc_write_volume_label (int f, unsigned long vlabel_start,
 		vtoc_error(unable_to_seek, "vtoc_write_volume_label",
 			   _("Could not write volume label."));
 
-	rc = write(f, vlabel, sizeof(volume_label_t));
-	if (rc != sizeof(volume_label_t))
+	rc = write(f, vlabel, sizeof(volume_label_t) - 4);
+	/* Subtract 4 to leave off the "fudge" variable when writing.
+           We only write CDL volume labels, never LDL or CMS.  */
+	if (rc != sizeof(volume_label_t) - 4)
 		vtoc_error(unable_to_write, "vtoc_write_volume_label",
 			   _("Could not write volume label."));
 
