@@ -1,7 +1,7 @@
 #!/bin/sh
 # Ensure that an HFS partition in a dos table gets the right ID
 
-# Copyright (C) 2010 Free Software Foundation, Inc.
+# Copyright (C) 2010-2011 Free Software Foundation, Inc.
 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,20 +16,12 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-if test "$VERBOSE" = yes; then
-  set -x
-  parted --version
-fi
-
-: ${srcdir=.}
-. $srcdir/t-lib.sh
+. "${srcdir=.}/init.sh"; path_prepend_ ../parted
 
 dev=loop-file
 ss=$sector_size_
 n_sectors=8000
 
-fail=0
-
 dd if=/dev/null of=$dev bs=$ss seek=$n_sectors || framework_failure
 
 # create a GPT partition table
